"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParseAssertion = exports.ParseMatch = void 0;
const builder_1 = require("./builder");
const CharactersMap = {
    ANY: ".",
    DIGIT: "\\d",
    NON_DIGIT: "\\D",
    ALPHANUM: "\\w",
    NON_ALPHANUM: "\\W",
    SPACE: "\\s",
    NON_SPACE: "\\S",
    HTAB: "\\t",
    VTAB: "\\v",
    RETURN: "\\r",
    LINEFEED: "\\n",
    FORMFEED: "\\f",
    BACKSPACE: "[\\b]",
    NULL: "(?:\\0)"
};
const ParseMatch = (character) => {
    if (typeof (character) === "number" && character in builder_1.Characters) {
        return CharactersMap[builder_1.Characters[character]];
    }
    if (typeof (character) === "string") {
        return EscapeCharacter(character);
    }
    if (typeof (character) === "object" && isLiteralCharacterInterface(character)) {
        return character.character;
    }
    throw new Error("Invalid input for match: " + character);
};
exports.ParseMatch = ParseMatch;
const isLiteralCharacterInterface = (object) => {
    return "character" in object;
};
const EscapeCharacter = (character) => {
    return character.replace(/[-[\]{}()*+?.,\\\/^$|#\s]/g, '\\$&');
};
const ParseAssertion = (assertion) => {
    if (typeof (assertion) === "number" && assertion in builder_1.Assertion) {
        return AssertionMap[builder_1.Assertion[assertion]];
    }
    throw new Error("Invalid input for assertion: " + assertion);
};
exports.ParseAssertion = ParseAssertion;
const AssertionMap = {
    START: "^",
    END: "$",
    WORD_BOUNDARY: "\\b",
    NOT_WORD_BOUNDARY: "\\B"
};
//# sourceMappingURL=builderHelpers.js.map